==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/el-GR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Αυτός ο χρήστης μπορεί να συνδεθεί',
    'activated_disabled_help_text' => 'Δεν μπορείτε να επεξεργαστείτε την κατάσταση ενεργοποίησης για το δικό σας λογαριασμό.',
    'assets_user'       => 'Περιουσιακά στοιχεία που έχει αντιστοιχιστεί σε: όνομα',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες των χρηστών: user_count. Λάβετε υπόψη ότι δεν μπορείτε να αλλάξετε τα δικά σας χαρακτηριστικά χρήστη χρησιμοποιώντας αυτήν τη φόρμα και πρέπει να κάνετε αλλαγές στον δικό σας χρήστη ξεχωριστά.',
    'bulk_update_help'	=> 'Αυτή η φόρμα σας επιτρέπει να ενημερώσετε ταυτόχρονα πολλούς χρήστες. Συμπληρώστε μόνο τα πεδία που πρέπει να αλλάξετε. Τα τυχόν κενά πεδία παραμένουν αμετάβλητα.',
    'current_assets'    => 'Περιουσιακά στοιχεία που ελέγχονται αυτήν τη στιγμή σε αυτόν τον χρήστη',
    'clone'             => 'Κλώνος χρήστη',
    'contact_user'      => 'Επικοινωνία :Όνομα',
    'edit'              => 'Επεξεργασία χρήστη',
    'filetype_info'     => 'Επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip και rar.',
    'history_user'      => 'Ιστορικό: όνομα',
    'info'				=> 'Πληροφορίες',
    'restore_user'		=> 'Κάντε κλικ εδώ για να τα επαναφέρετε.',
    'last_login'        => 'Τελευταία σύνδεση',
    'ldap_config_text'  => 'Οι ρυθμίσεις διαμόρφωσης LDAP μπορούν να βρεθούν στο στοιχείο Διαχειριστής> Ρυθμίσεις. Η (επιλεγμένη) επιλεγμένη τοποθεσία θα οριστεί για όλους τους εισαγόμενους χρήστες.',
    'print_assigned'    => 'Εκτύπωση Όλων Των Ανατεθέντων',
    'email_assigned'    => 'Λίστα Email όλων των ανατεθέντων',
    'user_notified'     => 'Ο χρήστης έχει αποσταλεί μέσω ηλεκτρονικού ταχυδρομείου σε μια λίστα των αντιστοιχισμένων αντικειμένων του.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Συμπερίληψη αυτού του χρήστη κατά την αυτόματη εκχώρηση κατάλληλων αδειών',
    'auto_assign_help'  => 'Παράλειψη αυτού του χρήστη στην αυτόματη ανάθεση αδειών',
    'software_user'     => 'Λογισμικό Έγινε έλεγχος σε: όνομα',
    'send_email_help'   => 'Πρέπει να δώσετε μια διεύθυνση ηλεκτρονικού ταχυδρομείου για αυτόν τον χρήστη για να του στείλει τα διαπιστευτήρια. Τα στοιχεία ηλεκτρονικού ταχυδρομείου μπορούν να γίνουν μόνο κατά τη δημιουργία του χρήστη. Οι κωδικοί πρόσβασης αποθηκεύονται με μονόδρομο hash και δεν μπορούν να ανακτηθούν μόλις αποθηκευτούν.',
    'view_user'         => 'Προβολή χρήστη :ονόματος',
    'usercsv'           => 'CSV αρχείο',
    'two_factor_admin_optin_help' => 'Οι τρέχουσες ρυθμίσεις διαχειριστή επιτρέπουν την επιλεκτική εφαρμογή ελέγχου ταυτότητας δύο παραγόντων.',
    'two_factor_enrolled' => 'Συσκευή εγγραφής 2FA',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'Ο χρήστης δεν μπορεί να συνδεθεί',
    'user_activated'  => 'Ο χρήστης μπορεί να συνδεθεί',
    'activation_status_warning' => 'Να μην αλλάζει η κατάσταση ενεργοποίησης',
    'group_memberships_helpblock' => 'Μόνο οι υπερδιαχειριστές μπορούν να επεξεργαστούν τις συνδρομές ομάδας.',
    'superadmin_permission_warning' => 'Μόνο οι υπερδιαχειριστές μπορούν να παρέχουν πρόσβαση σε υπερδιαχειριστή χρήστη.',
    'admin_permission_warning' => 'Μόνο χρήστες με δικαιώματα διαχειριστών ή μεγαλύτερα μπορούν να παρέχουν πρόσβαση σε έναν διαχειριστή χρήστη.',
    'remove_group_memberships' => 'Αφαίρεση Μελών Ομάδας',
    'warning_deletion_information' => 'Πρόκειται να ελέγξετε όλα τα στοιχεία από τους :count χρήστες παρακάτω. Τα ονόματα Super admin επισημαίνονται με κόκκινο χρώμα.',
    'update_user_assets_status' => 'Ενημέρωση όλων των περιουσιακών στοιχείων για αυτούς τους χρήστες σε αυτή την κατάσταση',
    'checkin_user_properties' => 'Ελέγξτε όλες τις ιδιότητες που σχετίζονται με αυτούς τους χρήστες',
    'remote_label'   => 'Αυτός είναι ένας απομακρυσμένος χρήστης',
    'remote'   => 'Απομακρυσμένο',
    'remote_help' => 'Αυτό μπορεί να είναι χρήσιμο αν χρειαστεί να φιλτράρετε από απομακρυσμένους χρήστες που δεν εισέρχονται ποτέ ή σπάνια στις φυσικές σας τοποθεσίες.',
    'not_remote_label' => 'Αυτός δεν είναι απομακρυσμένος χρήστης',
    'vip_label' => 'VIP χρήστης',
    'vip_help' => 'Αυτό μπορεί να είναι χρήσιμο για να επισημάνετε σημαντικούς ανθρώπους στον οργανισμό σας, αν θέλετε να τους χειριστείτε με ειδικούς τρόπους.',
    'create_user' => 'Δημιουργία χρήστη',
    'create_user_page_explanation' => 'Αυτές είναι οι πληροφορίες λογαριασμού που θα χρησιμοποιήσετε για να αποκτήσετε πρόσβαση στην ιστοσελίδα για πρώτη φορά.',
    'email_credentials' => 'Πιστοποιητικά ηλεκτρονικού ταχυδρομείου',
    'email_credentials_text' => 'Αποστολή των διαπιστευτηρίων μου στη διεύθυνση ηλεκτρονικού ταχυδρομείου παραπάνω',
    'next_save_user' => 'Επόμενο: Αποθήκευση Χρήστη',
    'all_assigned_list_generation' => 'Δημιουργήθηκε στις:',
    'email_user_creds_on_create' => 'Στείλτε email στο χρήστη τα διαπιστευτήριά τους?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/el-GR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Αυτός ο χρήστης μπορεί να συνδεθεί',
    'activated_disabled_help_text' => 'Δεν μπορείτε να επεξεργαστείτε την κατάσταση ενεργοποίησης για το δικό σας λογαριασμό.',
    'assets_user'       => 'Περιουσιακά στοιχεία που έχει αντιστοιχιστεί σε: όνομα',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες των χρηστών: user_count. Λάβετε υπόψη ότι δεν μπορείτε να αλλάξετε τα δικά σας χαρακτηριστικά χρήστη χρησιμοποιώντας αυτήν τη φόρμα και πρέπει να κάνετε αλλαγές στον δικό σας χρήστη ξεχωριστά.',
    'bulk_update_help'	=> 'Αυτή η φόρμα σας επιτρέπει να ενημερώσετε ταυτόχρονα πολλούς χρήστες. Συμπληρώστε μόνο τα πεδία που πρέπει να αλλάξετε. Τα τυχόν κενά πεδία παραμένουν αμετάβλητα.',
    'current_assets'    => 'Περιουσιακά στοιχεία που ελέγχονται αυτήν τη στιγμή σε αυτόν τον χρήστη',
    'clone'             => 'Κλώνος χρήστη',
    'contact_user'      => 'Επικοινωνία :Όνομα',
    'edit'              => 'Επεξεργασία χρήστη',
    'filetype_info'     => 'Επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip και rar.',
    'history_user'      => 'Ιστορικό: όνομα',
    'info'				=> 'Πληροφορίες',
    'restore_user'		=> 'Κάντε κλικ εδώ για να τα επαναφέρετε.',
    'last_login'        => 'Τελευταία σύνδεση',
    'ldap_config_text'  => 'Οι ρυθμίσεις διαμόρφωσης LDAP μπορούν να βρεθούν στο στοιχείο Διαχειριστής> Ρυθμίσεις. Η (επιλεγμένη) επιλεγμένη τοποθεσία θα οριστεί για όλους τους εισαγόμενους χρήστες.',
    'print_assigned'    => 'Εκτύπωση Όλων Των Ανατεθέντων',
    'email_assigned'    => 'Λίστα Email όλων των ανατεθέντων',
    'user_notified'     => 'Ο χρήστης έχει αποσταλεί μέσω ηλεκτρονικού ταχυδρομείου σε μια λίστα των αντιστοιχισμένων αντικειμένων του.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Συμπερίληψη αυτού του χρήστη κατά την αυτόματη εκχώρηση κατάλληλων αδειών',
    'auto_assign_help'  => 'Παράλειψη αυτού του χρήστη στην αυτόματη ανάθεση αδειών',
    'software_user'     => 'Λογισμικό Έγινε έλεγχος σε: όνομα',
    'view_user'         => 'Προβολή χρήστη :ονόματος',
    'usercsv'           => 'CSV αρχείο',
    'two_factor_admin_optin_help' => 'Οι τρέχουσες ρυθμίσεις διαχειριστή επιτρέπουν την επιλεκτική εφαρμογή ελέγχου ταυτότητας δύο παραγόντων.',
    'two_factor_enrolled' => 'Συσκευή εγγραφής 2FA',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'Ο χρήστης δεν μπορεί να συνδεθεί',
    'user_activated'  => 'Ο χρήστης μπορεί να συνδεθεί',
    'activation_status_warning' => 'Να μην αλλάζει η κατάσταση ενεργοποίησης',
    'group_memberships_helpblock' => 'Μόνο οι υπερδιαχειριστές μπορούν να επεξεργαστούν τις συνδρομές ομάδας.',
    'superadmin_permission_warning' => 'Μόνο οι υπερδιαχειριστές μπορούν να παρέχουν πρόσβαση σε υπερδιαχειριστή χρήστη.',
    'admin_permission_warning' => 'Μόνο χρήστες με δικαιώματα διαχειριστών ή μεγαλύτερα μπορούν να παρέχουν πρόσβαση σε έναν διαχειριστή χρήστη.',
    'remove_group_memberships' => 'Αφαίρεση Μελών Ομάδας',
    'warning_deletion_information' => 'Πρόκειται να ελέγξετε όλα τα στοιχεία από τους :count χρήστες παρακάτω. Τα ονόματα Super admin επισημαίνονται με κόκκινο χρώμα.',
    'update_user_assets_status' => 'Ενημέρωση όλων των περιουσιακών στοιχείων για αυτούς τους χρήστες σε αυτή την κατάσταση',
    'checkin_user_properties' => 'Ελέγξτε όλες τις ιδιότητες που σχετίζονται με αυτούς τους χρήστες',
    'remote_label'   => 'Αυτός είναι ένας απομακρυσμένος χρήστης',
    'remote'   => 'Απομακρυσμένο',
    'remote_help' => 'Αυτό μπορεί να είναι χρήσιμο αν χρειαστεί να φιλτράρετε από απομακρυσμένους χρήστες που δεν εισέρχονται ποτέ ή σπάνια στις φυσικές σας τοποθεσίες.',
    'not_remote_label' => 'Αυτός δεν είναι απομακρυσμένος χρήστης',
    'vip_label' => 'VIP χρήστης',
    'vip_help' => 'Αυτό μπορεί να είναι χρήσιμο για να επισημάνετε σημαντικούς ανθρώπους στον οργανισμό σας, αν θέλετε να τους χειριστείτε με ειδικούς τρόπους.',
    'create_user' => 'Δημιουργία χρήστη',
    'create_user_page_explanation' => 'Αυτές είναι οι πληροφορίες λογαριασμού που θα χρησιμοποιήσετε για να αποκτήσετε πρόσβαση στην ιστοσελίδα για πρώτη φορά.',
    'email_credentials' => 'Πιστοποιητικά ηλεκτρονικού ταχυδρομείου',
    'email_credentials_text' => 'Αποστολή των διαπιστευτηρίων μου στη διεύθυνση ηλεκτρονικού ταχυδρομείου παραπάνω',
    'next_save_user' => 'Επόμενο: Αποθήκευση Χρήστη',
    'all_assigned_list_generation' => 'Δημιουργήθηκε στις:',
    'email_user_creds_on_create' => 'Στείλτε email στο χρήστη τα διαπιστευτήριά τους?',
    'department_manager' => 'Department Manager',
];
